fix govpp, add more checks to makefile
[govpp.git] / govpp.go
index 82ee5f8..d66d5dc 100644 (file)
--- a/govpp.go
+++ b/govpp.go
 package govpp
 
 import (
-       "gerrit.fd.io/r/govpp.git/adapter"
-       "gerrit.fd.io/r/govpp.git/adapter/vppapiclient"
-       "gerrit.fd.io/r/govpp.git/core"
+       "git.fd.io/govpp.git/adapter"
+       "git.fd.io/govpp.git/adapter/vppapiclient"
+       "git.fd.io/govpp.git/core"
+       "time"
 )
 
-var vppAdapter adapter.VppAdapter // VPP Adapter that will be used in the subsequent Connect calls
+var (
+       // VPP binary API adapter that will be used in the subsequent Connect calls
+       vppAdapter adapter.VppAPI
+)
 
-// Connect connects the govpp core to VPP either using the default VPP Adapter, or using the adapter previously
-// set by SetAdapter (useful mostly just for unit/integration tests with mocked VPP adapter).
-func Connect() (*core.Connection, error) {
+func getVppAdapter(shm string) adapter.VppAPI {
        if vppAdapter == nil {
-               vppAdapter = vppapiclient.NewVppAdapter()
+               vppAdapter = vppapiclient.NewVppClient(shm)
        }
-       return core.Connect(vppAdapter)
+       return vppAdapter
+}
+
+// SetVppAdapter sets the adapter that will be used for connections to VPP in the subsequent `Connect` calls.
+func SetVppAdapter(a adapter.VppAPI) {
+       vppAdapter = a
+}
+
+// Connect connects the govpp core to VPP either using the default VPP Adapter, or using the adapter previously
+// set by SetAdapter (useful mostly just for unit/integration tests with mocked VPP adapter).
+// This call blocks until VPP is connected, or an error occurs. Only one connection attempt will be performed.
+func Connect(shm string) (*core.Connection, error) {
+       return core.Connect(getVppAdapter(shm))
 }
 
-// SetAdapter sets the adapter that will be used for connections to VPP in the subsequent `Connect` calls.
-func SetAdapter(ad adapter.VppAdapter) {
-       vppAdapter = ad
+// AsyncConnect asynchronously connects the govpp core to VPP either using the default VPP Adapter,
+// or using the adapter previously set by SetAdapter.
+// This call does not block until connection is established, it returns immediately. The caller is
+// supposed to watch the returned ConnectionState channel for Connected/Disconnected events.
+// In case of disconnect, the library will asynchronously try to reconnect.
+func AsyncConnect(shm string, attempts int, interval time.Duration) (*core.Connection, chan core.ConnectionEvent, error) {
+       return core.AsyncConnect(getVppAdapter(shm), attempts, interval)
 }